@@ -296,16 +296,16 @@ def monitor_view():
 
             time.sleep(wTime)
 
-    except ProcessLookupError as e:
-        print('End of monitoring：{}'.format(e))
+    except KeyboardInterrupt:
+        print('------------------ 监控服务已停止！-----------------')
         pass
 
 
 def monitor_on():
     try:
         print('Grafana url：{}'.format(grafana_tools()))
+        print('-------------- 监控服务运行中，请勿关闭！--------------')
         monitor_view()
-        print('监控服务运行中，请勿关闭！')
 
-    except TypeError as E:
-        print('监控服务启动异常：{}'.format(E))
+    except Exception as E:
+        print('监控服务运行异常：{}'.format(E))
